Annalist built-in data types:

Literals:

- Text
- Longtext
- Slug
- Identifier (URI/CURIE)
- Number
- Date
- Image
- Link

References:

- Type
- List
- View
- Field

Specials:

- Placement
- RenderType
- Field

